public with sharing class TestChangeSigner {
    public String createPackageAllowChangeSigner(){
        ESignLiveSDK sdk = new ESignLiveSDK();
         
        //Create package
        ESignLiveAPIObjects.Package_x pkg = new ESignLiveAPIObjects.Package_x();
        pkg.name = 'Test Change Signer - ' + Datetime.now().format();
        pkg.status = ESignLiveAPIObjects.PackageStatus.SENT;
        
        //Create Roles
        String roleId = 'signer1';
        ESignLiveAPIObjects.Role signer1 = createRoleAllowChangeSigner(roleId,'John','Smith','liangduo1993@gmail.com');
        
        pkg.roles = new List<ESignLiveAPIObjects.Role>{signer1};    //add role
        
        
        //Prepare Documents Blob
        String document1Name = 'Sample Document';
        StaticResource sr = [SELECT Id, Body FROM StaticResource WHERE Name = 'testdoc1' LIMIT 1];
        Map<String,Blob> documentBlobMap = new Map<String,Blob>();
        documentBlobMap.put(document1Name, sr.Body);
         
        //Create Document Metadata
        ESignLiveAPIObjects.Document document1 = new ESignLiveAPIObjects.Document();
        document1.name = document1Name;
        document1.id = 'document1';
         
        //Create Field &Approval
        ESignLiveAPIObjects.Field field = new ESignLiveAPIObjects.Field();
        field.left = 208;
        field.width = 200;
        field.height = 50;
        field.top = 518;
        field.page = 0;
        field.subtype = 'FULLNAME';
        field.type = 'SIGNATURE';
         
        List<ESignLiveAPIObjects.Field> fields = new List<ESignLiveAPIObjects.Field>();
        fields.add(field);
         
        ESignLiveAPIObjects.Approval approval1 = new ESignLiveAPIObjects.Approval();
        approval1.fields = fields;    //add field
        approval1.role = roleId;
        document1.approvals = new List<ESignLiveAPIObjects.Approval>{approval1};    //add approval
        
        pkg.documents = new List<ESignLiveAPIObjects.Document>{document1};    //add document
        
        //Send package One Step
        String packageId = sdk.createPackage(pkg,documentBlobMap);
        System.debug('PackageId: ' + packageId);
        return packageId;
    }
    
    
    public ESignLiveAPIObjects.Role createRoleAllowChangeSigner(String id, String firstName, String lastName, String email){
        ESignLiveAPIObjects.Role role = new ESignLiveAPIObjects.Role();
        ESignLiveValidation.validate('Email', email);
        ESignLiveValidation.validate('First Name', firstname);
        ESignLiveValidation.validate('Last Name', lastname);
        
        ESignLiveAPIObjects.Signer signer = new ESignLiveAPIObjects.Signer();
        signer.firstName = firstName;
        signer.lastName = lastName;
        signer.email = email;
        signer.name = firstName + lastName;
        signer.id = id;

        List<ESignLiveAPIObjects.Signer> signers = new List<ESignLiveAPIObjects.Signer>();
        signers.add(signer);
        role.signers = signers;
        role.id = id;
        role.reassign = true;	//allow change signer
        
        return role;   
    }
}